diff --git a/Raylib-cs/interop/Raylib.cs b/Raylib-cs/interop/Raylib.cs
index 37aaef6..77573fe 100644
--- a/Raylib-cs/interop/Raylib.cs
+++ b/Raylib-cs/interop/Raylib.cs
@@ -1219,9 +1219,18 @@ public static unsafe partial class Raylib
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern void DrawRectangleRounded(Rectangle rec, float roundness, int segments, Color color);
/// Draw rectangle with rounded edges outline
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern void DrawRectangleRoundedLines(
+ Rectangle rec,
+ float roundness,
+ int segments,
+ Color color
+ );
+
+ // Draw rectangle with rounded edges outline
+ [DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
+ public static extern void DrawRectangleRoundedLinesEx(
Rectangle rec,
float roundness,
int segments,
@@ -1219,9 +1219,18 @@ public static unsafe partial class Raylib
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern void DrawRectangleRounded(Rectangle rec, float roundness, int segments, Color color);
- /// Draw rectangle with rounded edges outline
+ /// Draw rectangle lines with rounded edges/summary>
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern void DrawRectangleRoundedLines(